@@ -229,7 +229,7 @@ class xtable:
             row = dict()
             for ix, val in enumerate(r):
                 if forcestring :
-                    row[self.__header[ix]] = sr(val)
+                    row[self.__header[ix]] = str(val)
                 else :
                     row[self.__header[ix]] = val
             tbl.append(row)
@@ -243,7 +243,7 @@ class xtable:
             row = dict()
             for ix, val in enumerate(r):
                 if forcestring :
-                    row[self.__header[ix]] = sr(val)
+                    row[self.__header[ix]] = str(val)
                 else :
                     row[self.__header[ix]] = val
             tbl.append(row)
@@ -761,7 +761,7 @@ def xtable_main():
             sys.exit(0)
 
     import signal
-    TIMEOUT = 1
+    TIMEOUT = 10
     def interrupted(signal, frame):
         print("# timeout/no input from STDIN detected.",
               file=sys.stderr,
